@@ -16,13 +16,13 @@ class DingDingPlugin(NotificationPlugin):
     Sentry plugin to send error counts to DingDing.
     """
     author = 'dreamerldq'
-    author_url = 'https://github.com/cench/sentry-10-dingding'
-    version = '1.0.4'
+    author_url = 'https://github.com/dreamerldq/sentry-dingding-format'
+    version = '1.0.5'
     description = 'Send project error counts to DingDing .'
     resource_links = [
         ('Source', 'https://github.com/cench/sentry-10-dingding'),
-        ('Bug Tracker', 'https://github.com/cench/sentry-10-dingding/issues'),
-        ('README', 'https://github.com/cench/sentry-10-dingding/blob/master/README.md'),
+        ('Bug Tracker', 'https://github.com/dreamerldq/sentry-dingding-format/issues'),
+        ('README', 'https://github.com/dreamerldq/sentry-dingding-format/blob/master/README.md'),
     ]
 
     slug = 'WbDingDing'
@@ -58,8 +58,10 @@ class DingDingPlugin(NotificationPlugin):
             "msgtype": "markdown",
             "markdown": {
                 "title": title,
-                "text": u"#### {title} \n\n > {title} \n\n > {path} \n\n [详细信息]({url})".format(
+                "text": u"#### {title} \n\n > {message} \n\n > {device} \n\n > {uid} \n\n > {path} \n\n [详细信息]({url})".format(
                     title=title,
+                    device=event.get_tag('device'),
+                    uid=event.get_tag('uid'),
                     path=event.get_tag('url'),
                     message=event.title or event.message,
                     url=u"{}events/{}/".format(group.get_absolute_url(), event.event_id),
